@@ -47,7 +47,7 @@ class BryantEvolutionLocalClient:
             self._file = await aiofiles.open(self._tty, mode="r+b", buffering=0)
 
         async def write(self, s: str) -> None:
-            await self._file.write(f"{s}\n")
+            await self._file.write(f"{s}\n".encode('ascii'))
 
         async def read_next(self) -> str:
             while True:
